@@ -14,25 +14,13 @@
 #' @export
 #' @references Hadley Wickham (2011). The Split-Apply-Combine Strategy for
 #'   Data Analysis. Journal of Statistical Software, 40(1), 1-29.
-#'   \url{http://www.jstatsoft.org/v40/i01/}.
+#'   \url{https://www.jstatsoft.org/v40/i01/}.
 #' @examples
 #' r_ply(10, plot(runif(50)))
 #' r_ply(25, hist(runif(1000)))
 r_ply <- function(.n, .expr, .progress = "none", .print = FALSE) {
-  if (is.function(.expr)) {
-    f <- .expr
-  } else {
-    f <- eval.parent(substitute(function() .expr))
-  }
-
-  progress <- create_progress_bar(.progress)
-
-  progress$init(.n)
-  on.exit(progress$term())
-
-  for(i in seq_len(.n)) {
-    f()
-    progress$step()
-  }
-  progress$term()
+  .rlply_worker(.n, .progress,
+                eval.parent(substitute(function() .expr)),
+                .discard = TRUE, .print = .print)
+  invisible(NULL)
 }
